/**
 * \file config_arduinoUno.h
 *
 *  Configuration settings for the ArduinoUno evaluation board
 *
 *  This file contains some platform specific definitions concerning software
 *  and hardware configuration. These settings influence the compilation and
 *  build process. Most of those settings can't be changed later at runtime.
 *
 *  Platform: arduinoUno; CPU: ATmega328p;
 *  atmega328p   # takes avr\iom328p.h
 *
 *  Hardware specifica and settings:
 *
 *  Port B: 5= yeLED; 5-4-3= ISP set as input <br />
 *  Port C: usable as analogue input <br />
 *  Port D: 0,1 = R/TxD (UART); 7= buzzer; 6= rdLED;
 *          5= TestPin0; 4= TestPin1 <br />
 *
 * This file is part of weAutSys &nbsp;
 *          <<a href="http://weinert-automation.de">weinert-automation.de</a>>
 * <br />It is also used for the \ref bootSup "serial bootloader".
 *
 * &nbsp; \ref copyLicNote " Copyright &copy; " 2014  Albrecht Weinert, Bochum
 * \author  Albrecht Weinert  &nbsp; <<a href="http://a-weinert.de">a-weinert.de</a>>
 * $Revision: 1 $
 * $Date: 2017-01-25 11:03:06 +0000 (Wed, 25 Jan 2017) $
 */
//  SVN last change by $Author: albrecht $

/** @} */ // Doxygen addtogroup   comTypes
/** @} */ // Doxygen addtogroup appLaySup

#ifndef CONFIG_PLATFORM_H
# define CONFIG_PLATFORM_H arduinoUno
#else
# error "more than one platform specific config_platform.h file"
#endif

//--- platform specifica on ports ----------------------------------------

#define HAVE_NIC 0 //!< Network interface chip;  0: no switch \showinitializer
#define HAVE_SMC 0 //!< Small memory card;  0: no switch \showinitializer

#define HAVE_ETHERNET 0 //!< Ethernet available \showinitializer
#define HAVE_MODBUS 0 //!< Modbus on Ethernet available \showinitializer

#define UART0MAY_CTS 0  //!< UART0 may signal ability to receive by CTS \showinitializer
#define UART0MAY_RTS 0  //!< UART0 may use RTS to hold back sending \showinitializer
#define UART0SPIYKY 1 //!< UART0 has spiky USB2serial: filter FE,FF \showinitializer

#define GN_LED_PORT B //!< Port for yellow Status LED \showinitializer
#define GN_LED_PIN 5 //!< Pin for yellow Status LED \showinitializer
#define RD_LED_PORT D //!< Port reserved for red Status LED \showinitializer
#define RD_LED_PIN 6 //!< Pin reserved for red Status LED \showinitializer

#define BUZZER_PORT D //!< Port for buzzer (if any)  \showinitializer
#define BUZZER_PIN 7  //!< Pin for buzzer (if any) \showinitializer

#undef CHAIN8LED_PORT //!< No Port for 8 independent LEDs in a row  \showinitializer
#define NO_CHAIN8LED  //!< No 8 independent LEDs in a row  \showinitializer


/** Port initialisation
 *
 *  This macro does the basic port initialisation according to the platform's
 *  standard port usage. Anyway it has to cover the serial bootloader.
 */
#define BASIC_INIT() do { \
   DDRB = 0x20;  /* 5: yeLED;  */ \
   PORTB = 0x20; /* yeLED  on */   \
   DDRC  = 0;    /* basically all input */ \
   PORTC = 0xFF; /* pullups on  */   \
   DDRD = 0xF2;  /* 0:RxD; 1:TxD (out); 5,4:testPin0,1; 6:rdLED; 7:buzzer */\
   PORTD = 3;    /* RxD0, TxD0 1 resp. pull-up */ \
}while(0)


/** Have and use a bootloader
 *
 *  This value determines the existence and usage of a bootloader:<br />
 *  0: no bootloader or at least no bootloader integration
 *  1: bootloader area used / bootloader existing
 *  2: bootloader fully integrated: application programme may use all
 *     No Read-While-Write (NRWW) flash section functions and constants.
 *
 *  Fully integrated (2) means that all Controller resets go through the
 *  bootloader. And the bootloader will not enter the program (=x00000)
 *  without having done all basic \ref BASIC_INIT() "initialisations", that
 *  hence can be omitted from system/application software. Full integration
 *  also means that the bootloader may be entered by (\ref shellCLI "CLI")
 *  command.
 *  \showinitializer
 */
#define USE_BOOTLOADER_PRESET 2

// no extra HW criterion (button) to enter / stay in bootloader
#define hwCritEntBoot() (0)

// Two bootloader settings (must either both or none be defined)
#define PROG_HW_VER "32" //!< The \ref programmerHWver \showinitializer
#define TIMEOUT_LIGHTSHOW 0 //!< No timeout light show so far \showinitializer


/** Allow low grade crystal for CPU clock
 *
 * Arduinos (platforms arduMega2560 and arduinoUno) have so low grade crystals
 * that you either have to repair the (new) board or measure the real
 * frequency and define it as macro shitCrystal.
 *
 * If this macro ALLOW_shitCrystal is defined a value defined in shitCrystal
 * will be used in some places instead of the nominal F_CPU.
 * \showinitializer
 */
#define ALLOW_shitCrystal 1

# ifndef F_CPU
#  define F_CPU  16000000
# elif  F_CPU != 16000000
// warning only because of the low grade Arduino crystals
#  warning "non standard MCU frequency specified for platform (check)"
# endif
